@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -647,6 +647,8 @@ thunar_history_show_menu (GtkAction     *action,
               image = gtk_image_new_from_pixbuf (icon);
               g_object_unref (G_OBJECT (icon));
             }
+
+          g_object_unref (file);
         }
 
       if (image == NULL)
